from typing import Dict, Optional


class LambdaResponse(object):
    def __init__(self,
                 status: int,
                 response: Optional[bytes],
                 headers: Optional[Dict[str, str]]):
        self.lambda_return = {
            "statusCode": status,
            "body": response,
            "headers": headers
        }
